@@ -15,6 +15,7 @@ import (
 	"testing"
 
 	"github.com/getkin/kin-openapi/openapi3"
+	legacyrouter "github.com/getkin/kin-openapi/routers/legacy"
 	"github.com/stretchr/testify/require"
 )
 
@@ -44,7 +45,7 @@ func TestFilter(t *testing.T) {
 	complexArgSchema.Required = []string{"name", "id"}
 
 	// Declare router
-	swagger := &openapi3.Swagger{
+	doc := &openapi3.T{
 		OpenAPI: "3.0.0",
 		Info: &openapi3.Info{
 			Title:   "MyAPI",
@@ -61,9 +62,10 @@ func TestFilter(t *testing.T) {
 					Parameters: openapi3.Parameters{
 						{
 							Value: &openapi3.Parameter{
-								In:     "path",
-								Name:   "pathArg",
-								Schema: openapi3.NewStringSchema().WithMaxLength(2).NewRef(),
+								In:       "path",
+								Name:     "pathArg",
+								Schema:   openapi3.NewStringSchema().WithMaxLength(2).NewRef(),
+								Required: true,
 							},
 						},
 						{
@@ -103,7 +105,7 @@ func TestFilter(t *testing.T) {
 								).NewRef(),
 							},
 						},
-						// TODO(decode not): handle decoding "not" JSON Schema
+						// TODO(decode not): handle decoding "not" Schema
 						// {
 						// 	Value: &openapi3.Parameter{
 						// 		In:   "query",
@@ -154,14 +156,18 @@ func TestFilter(t *testing.T) {
 		},
 	}
 
-	router := NewRouter().WithSwagger(swagger)
+	err := doc.Validate(context.Background())
+	require.NoError(t, err)
+	router, err := legacyrouter.NewRouter(doc)
+	require.NoError(t, err)
 	expectWithDecoder := func(req ExampleRequest, resp ExampleResponse, decoder ContentParameterDecoder) error {
 		t.Logf("Request: %s %s", req.Method, req.URL)
-		httpReq, _ := http.NewRequest(req.Method, req.URL, marshalReader(req.Body))
-		httpReq.Header.Set("Content-Type", req.ContentType)
+		httpReq, err := http.NewRequest(req.Method, req.URL, marshalReader(req.Body))
+		require.NoError(t, err)
+		httpReq.Header.Set(headerCT, req.ContentType)
 
 		// Find route
-		route, pathParams, err := router.FindRoute(httpReq.Method, httpReq.URL)
+		route, pathParams, err := router.FindRoute(httpReq)
 		require.NoError(t, err)
 
 		// Validate request
@@ -179,7 +185,7 @@ func TestFilter(t *testing.T) {
 			RequestValidationInput: requestValidationInput,
 			Status:                 resp.Status,
 			Header: http.Header{
-				"Content-Type": []string{
+				headerCT: []string{
 					resp.ContentType,
 				},
 			},
@@ -197,15 +203,12 @@ func TestFilter(t *testing.T) {
 		return expectWithDecoder(req, resp, nil)
 	}
 
-	var err error
-	var req ExampleRequest
-	var resp ExampleResponse
-	resp = ExampleResponse{
+	resp := ExampleResponse{
 		Status: 200,
 	}
 	// Test paths
 
-	req = ExampleRequest{
+	req := ExampleRequest{
 		Method: "POST",
 		URL:    "http://example.com/api/prefix/v/suffix",
 	}
@@ -286,7 +289,7 @@ func TestFilter(t *testing.T) {
 	err = expect(req, resp)
 	require.IsType(t, &RequestError{}, err)
 
-	// TODO(decode not): handle decoding "not" JSON Schema
+	// TODO(decode not): handle decoding "not" Schema
 	// req = ExampleRequest{
 	// 	Method: "POST",
 	// 	URL:    "http://example.com/api/prefix/v/suffix?queryArgNot=abdfg",
@@ -294,7 +297,7 @@ func TestFilter(t *testing.T) {
 	// err = expect(req, resp)
 	// require.IsType(t, &RequestError{}, err)
 
-	// TODO(decode not): handle decoding "not" JSON Schema
+	// TODO(decode not): handle decoding "not" Schema
 	// req = ExampleRequest{
 	// 	Method: "POST",
 	// 	URL:    "http://example.com/api/prefix/v/suffix?queryArgNot=123",
@@ -433,7 +436,7 @@ func TestValidateRequestBody(t *testing.T) {
 		t.Run(tc.name, func(t *testing.T) {
 			req := httptest.NewRequest(http.MethodPost, "/test", tc.data)
 			if tc.mime != "" {
-				req.Header.Set(http.CanonicalHeaderKey("Content-Type"), tc.mime)
+				req.Header.Set(headerCT, tc.mime)
 			}
 			inp := &RequestValidationInput{Request: req}
 			err := ValidateRequestBody(context.Background(), inp, tc.body)
@@ -477,8 +480,7 @@ func toJSON(v interface{}) io.Reader {
 	return bytes.NewReader(data)
 }
 
-// TestOperationOrSwaggerSecurity asserts that the swagger's SecurityRequirements are used if no SecurityRequirements are provided for an operation.
-func TestOperationOrSwaggerSecurity(t *testing.T) {
+func TestRootSecurityRequirementsAreUsedIfNotProvidedAtTheOperationLevel(t *testing.T) {
 	// Create the security schemes
 	securitySchemes := []ExampleSecurityScheme{
 		{
@@ -527,8 +529,7 @@ func TestOperationOrSwaggerSecurity(t *testing.T) {
 		},
 	}
 
-	// Create the swagger
-	swagger := &openapi3.Swagger{
+	doc := &openapi3.T{
 		OpenAPI: "3.0.0",
 		Info: &openapi3.Info{
 			Title:   "MyAPI",
@@ -547,12 +548,12 @@ func TestOperationOrSwaggerSecurity(t *testing.T) {
 
 	// Add the security schemes to the components
 	for _, scheme := range securitySchemes {
-		swagger.Components.SecuritySchemes[scheme.Name] = &openapi3.SecuritySchemeRef{
+		doc.Components.SecuritySchemes[scheme.Name] = &openapi3.SecuritySchemeRef{
 			Value: scheme.Scheme,
 		}
 	}
 
-	// Add the paths from the test cases to the swagger's paths
+	// Add the paths from the test cases to the spec's paths
 	for _, tc := range tc {
 		var securityRequirements *openapi3.SecurityRequirements = nil
 		if tc.schemes != nil {
@@ -562,7 +563,7 @@ func TestOperationOrSwaggerSecurity(t *testing.T) {
 			}
 			securityRequirements = tempS
 		}
-		swagger.Paths[tc.name] = &openapi3.PathItem{
+		doc.Paths[tc.name] = &openapi3.PathItem{
 			Get: &openapi3.Operation{
 				Security:  securityRequirements,
 				Responses: openapi3.NewResponses(),
@@ -570,8 +571,10 @@ func TestOperationOrSwaggerSecurity(t *testing.T) {
 		}
 	}
 
-	// Declare the router
-	router := NewRouter().WithSwagger(swagger)
+	err := doc.Validate(context.Background())
+	require.NoError(t, err)
+	router, err := legacyrouter.NewRouter(doc)
+	require.NoError(t, err)
 
 	// Test each case
 	for _, path := range tc {
@@ -587,15 +590,14 @@ func TestOperationOrSwaggerSecurity(t *testing.T) {
 
 		// Create the request
 		emptyBody := bytes.NewReader(make([]byte, 0))
-		pathURL, err := url.Parse(path.name)
-		require.NoError(t, err)
-		route, _, err := router.FindRoute(http.MethodGet, pathURL)
+		httpReq := httptest.NewRequest(http.MethodGet, path.name, emptyBody)
+		route, _, err := router.FindRoute(httpReq)
 		require.NoError(t, err)
 		req := RequestValidationInput{
-			Request: httptest.NewRequest(http.MethodGet, path.name, emptyBody),
+			Request: httpReq,
 			Route:   route,
 			Options: &Options{
-				AuthenticationFunc: func(c context.Context, input *AuthenticationInput) error {
+				AuthenticationFunc: func(ctx context.Context, input *AuthenticationInput) error {
 					if schemesValidated != nil {
 						if validated, ok := (*schemesValidated)[input.SecurityScheme]; ok {
 							if validated {
@@ -661,8 +663,7 @@ func TestAnySecurityRequirementMet(t *testing.T) {
 		},
 	}
 
-	// Create the swagger
-	swagger := openapi3.Swagger{
+	doc := openapi3.T{
 		OpenAPI: "3.0.0",
 		Info: &openapi3.Info{
 			Title:   "MyAPI",
@@ -674,9 +675,9 @@ func TestAnySecurityRequirementMet(t *testing.T) {
 		},
 	}
 
-	// Add the security schemes to the swagger's components
+	// Add the security schemes to the spec's components
 	for schemeName := range schemes {
-		swagger.Components.SecuritySchemes[schemeName] = &openapi3.SecuritySchemeRef{
+		doc.Components.SecuritySchemes[schemeName] = &openapi3.SecuritySchemeRef{
 			Value: &openapi3.SecurityScheme{
 				Type:   "http",
 				Scheme: "basic",
@@ -684,7 +685,7 @@ func TestAnySecurityRequirementMet(t *testing.T) {
 		}
 	}
 
-	// Add the paths to the swagger
+	// Add the paths to the spec
 	for _, tc := range tc {
 		// Create the security requirements from the test cases's schemes
 		securityRequirements := openapi3.NewSecurityRequirements()
@@ -693,7 +694,7 @@ func TestAnySecurityRequirementMet(t *testing.T) {
 		}
 
 		// Create the path with the security requirements
-		swagger.Paths[tc.name] = &openapi3.PathItem{
+		doc.Paths[tc.name] = &openapi3.PathItem{
 			Get: &openapi3.Operation{
 				Security:  securityRequirements,
 				Responses: openapi3.NewResponses(),
@@ -701,8 +702,10 @@ func TestAnySecurityRequirementMet(t *testing.T) {
 		}
 	}
 
-	// Create the router
-	router := NewRouter().WithSwagger(&swagger)
+	err := doc.Validate(context.Background())
+	require.NoError(t, err)
+	router, err := legacyrouter.NewRouter(&doc)
+	require.NoError(t, err)
 
 	// Create the authentication function
 	authFunc := makeAuthFunc(schemes)
@@ -711,7 +714,8 @@ func TestAnySecurityRequirementMet(t *testing.T) {
 		// Create the request input for the path
 		tcURL, err := url.Parse(tc.name)
 		require.NoError(t, err)
-		route, _, err := router.FindRoute(http.MethodGet, tcURL)
+		httpReq := httptest.NewRequest(http.MethodGet, tcURL.String(), nil)
+		route, _, err := router.FindRoute(httpReq)
 		require.NoError(t, err)
 		req := RequestValidationInput{
 			Route: route,
@@ -756,8 +760,7 @@ func TestAllSchemesMet(t *testing.T) {
 		},
 	}
 
-	// Create the swagger
-	swagger := openapi3.Swagger{
+	doc := openapi3.T{
 		OpenAPI: "3.0.0",
 		Info: &openapi3.Info{
 			Title:   "MyAPI",
@@ -769,9 +772,9 @@ func TestAllSchemesMet(t *testing.T) {
 		},
 	}
 
-	// Add the security schemes to the swagger's components
+	// Add the security schemes to the spec's components
 	for schemeName := range schemes {
-		swagger.Components.SecuritySchemes[schemeName] = &openapi3.SecuritySchemeRef{
+		doc.Components.SecuritySchemes[schemeName] = &openapi3.SecuritySchemeRef{
 			Value: &openapi3.SecurityScheme{
 				Type:   "http",
 				Scheme: "basic",
@@ -779,7 +782,7 @@ func TestAllSchemesMet(t *testing.T) {
 		}
 	}
 
-	// Add the paths to the swagger
+	// Add the paths to the spec
 	for _, tc := range tc {
 		// Create the security requirement for the path
 		securityRequirement := openapi3.SecurityRequirement{}
@@ -791,7 +794,7 @@ func TestAllSchemesMet(t *testing.T) {
 			}
 		}
 
-		swagger.Paths[tc.name] = &openapi3.PathItem{
+		doc.Paths[tc.name] = &openapi3.PathItem{
 			Get: &openapi3.Operation{
 				Security: &openapi3.SecurityRequirements{
 					securityRequirement,
@@ -801,8 +804,10 @@ func TestAllSchemesMet(t *testing.T) {
 		}
 	}
 
-	// Create the router from the swagger
-	router := NewRouter().WithSwagger(&swagger)
+	err := doc.Validate(context.Background())
+	require.NoError(t, err)
+	router, err := legacyrouter.NewRouter(&doc)
+	require.NoError(t, err)
 
 	// Create the authentication function
 	authFunc := makeAuthFunc(schemes)
@@ -811,7 +816,8 @@ func TestAllSchemesMet(t *testing.T) {
 		// Create the request input for the path
 		tcURL, err := url.Parse(tc.name)
 		require.NoError(t, err)
-		route, _, err := router.FindRoute(http.MethodGet, tcURL)
+		httpReq := httptest.NewRequest(http.MethodGet, tcURL.String(), nil)
+		route, _, err := router.FindRoute(httpReq)
 		require.NoError(t, err)
 		req := RequestValidationInput{
 			Route: route,
@@ -835,8 +841,8 @@ func TestAllSchemesMet(t *testing.T) {
 // makeAuthFunc creates an authentication function that accepts the given valid schemes.
 // If an invalid or unknown scheme is encountered, an error is returned by the returned function.
 // Otherwise the return value of the returned function is nil.
-func makeAuthFunc(schemes map[string]bool) func(c context.Context, input *AuthenticationInput) error {
-	return func(c context.Context, input *AuthenticationInput) error {
+func makeAuthFunc(schemes map[string]bool) func(ctx context.Context, input *AuthenticationInput) error {
+	return func(ctx context.Context, input *AuthenticationInput) error {
 		// If the scheme is valid and present in the schemes
 		valid, present := schemes[input.SecuritySchemeName]
 		if valid && present {
